@@ -101,9 +101,13 @@ class SmdaFunction(object):
 
     def _calculateNestingDepth(self):
         nesting_depth = 0
-        if self.blockrefs:
-            tree = build_dominator_tree(self.blockrefs, self.offset)
-            nesting_depth = get_nesting_depth(self.blockrefs, tree, self.offset)
+        try:
+            if self.blockrefs:
+                tree = build_dominator_tree(self.blockrefs, self.offset)
+                if tree:
+                    nesting_depth = get_nesting_depth(self.blockrefs, tree, self.offset)
+        except:
+            pass
         return nesting_depth
 
     def _calculatePicHash(self, binary_info):
@@ -112,8 +116,7 @@ class SmdaFunction(object):
             for instruction in block:
                 escaped_binary_seqs.append(instruction.getEscapedBinary(self._escaper, lower_addr=binary_info.base_addr, upper_addr=binary_info.base_addr + binary_info.binary_size))
         as_bytes = bytes([ord(c) for c in "".join(escaped_binary_seqs)])
-        return struct.unpack("Q", hashlib.sha256(as_bytes).digest()[:8])
-        # return int(hashlib.sha256(as_bytes).hexdigest()[:16], 16)
+        return struct.unpack("Q", hashlib.sha256(as_bytes).digest()[:8])[0]
 
     def _parseBlocks(self, block_dict):
         self.blocks = {}
@@ -123,7 +126,7 @@ class SmdaFunction(object):
             self.binweight += sum([len(ins.bytes) / 2 for ins in instructions])
 
     @classmethod
-    def fromDict(cls, function_dict, architecture=None):
+    def fromDict(cls, function_dict, binary_info=None, version=None):
         smda_function = cls(None)
         smda_function.offset = function_dict["offset"]
         smda_function.blocks = {}
@@ -138,11 +141,16 @@ class SmdaFunction(object):
         smda_function.confidence = function_dict["metadata"]["confidence"]
         smda_function.function_name = function_dict["metadata"]["function_name"]
         smda_function.pic_hash = function_dict["metadata"]["pic_hash"]
-        smda_function.nesting_depth = function_dict["metadata"]["nesting_depth"]
         smda_function.strongly_connected_components = function_dict["metadata"]["strongly_connected_components"]
         smda_function.tfidf = function_dict["metadata"]["tfidf"]
-        if architecture:
-            smda_function._escaper = IntelInstructionEscaper if architecture in ["intel"] else None
+        if binary_info.architecture:
+            smda_function._escaper = IntelInstructionEscaper if binary_info.architecture in ["intel"] else None
+        # modernize older reports on import
+        if version and version.startswith("1.2"):
+            smda_function.nesting_depth = smda_function._calculateNestingDepth()
+            smda_function.pic_hash = smda_function._calculatePicHash(binary_info)
+        else:
+            smda_function.nesting_depth = function_dict["metadata"]["nesting_depth"]
         return smda_function
 
     def toDict(self):
