@@ -1,8 +1,6 @@
 import struct
 import logging
 
-if len(logging._handlerList) == 0:
-    logging.basicConfig(level=logging.INFO, format="%(asctime)-15s %(message)s")
 LOG = logging.getLogger(__name__)
 
 LIEF_AVAILABLE = False
